@@ -43,36 +43,42 @@ class OnnxDType(str, enum.Enum):
     STRING = "string"
 
 class OnnxComponent(str, enum.Enum):
-    INPUT_TRANSLATOR = "InputTranslator"
-    OUTPUT_TRANSLATOR = "OutputTranslator"
-    POSTPROCESSOR = "PostProcessor"
-    ENCODER = "Encoder"
-    VARIABLE = "Variable"
-    TENSOR_VARIABLE = "TensorVariable"
-    SEQMAP_VARIABLE = "SeqMapVariable"
+    PREPROCESSOR = "Preprocessor"
+    PROBA_DECODER = "ProbaDecoder"
+    PRED_DECODER = "PredDecoder"
+    POST_PROCESSOR = "PostProcessor"
+    CLASSIFIER = "Classifier"
+
+class OnnxProbaDecoderTypes(str, enum.Enum):
+    TENSOR = "Tensor"
+    SEQMAP = "SeqMap"
+
+class PostProcessortype(str, enum.Enum):
+    IDENTITY = "Identity"
+    SIGMOID = "Sigmoid"
 
 
-@dataclass
+@dataclass(eq=True, order=True, frozen=True)
 class OnnxType:
     otype = OnnxTypeEnum.TYPE
     
 
-@dataclass
+@dataclass(eq=True, order=True, frozen=True)
 class OnnxBaseType(OnnxType):
     otype = OnnxTypeEnum.BASE_TYPE
     var_type: OnnxValueType
 
-@dataclass
+@dataclass(eq=True, order=True, frozen=True)
 class OnnxTensor(OnnxType):
     otype = OnnxTypeEnum.TENSOR
     dtype: OnnxDType
 
-@dataclass
+@dataclass(eq=True, order=True, frozen=True)
 class OnnxSequence(OnnxType):
     otype = OnnxTypeEnum.SEQUENCE
     item_type: OnnxType
 
-@dataclass
+@dataclass(eq=True, order=True, frozen=True)
 class OnnxMap(OnnxType):
     otype = OnnxTypeEnum.MAP
     key_type: OnnxType
@@ -80,7 +86,7 @@ class OnnxMap(OnnxType):
 
 Shape = Sequence[Optional[int]]
 
-@dataclass
+@dataclass(eq=True, order=True, frozen=True)
 class OnnxVariable:
     name: str
     vartype: OnnxType
